@@ -4,8 +4,7 @@ from .models import (
     FederationDescendant,
     FederationDescendantContact,
     FederationEntityProfile,
-    FederationEntityAssignedProfile,
-    StaffToken
+    FederationEntityAssignedProfile
 )
 
 
@@ -39,15 +38,6 @@ class FederationEntityProfileAdmin(admin.ModelAdmin):
     readonly_fields = ("trust_mark_template_as_json",)
 
 
-@admin.register(StaffToken)
-class StaffTokenAdmin(admin.ModelAdmin):
-    list_display = ("user", "expire_at", "is_valid")
-    list_filter = ("created", "modified", "expire_at")
-    search_fields = ("token", )
-    readonly_fields = ("is_valid",)
-    raw_id_fields = ('user',)
-
-
 @admin.register(FederationEntityAssignedProfile)
 class FederationEntityAssignedProfileAdmin(admin.ModelAdmin):
     list_display = ("descendant", "profile", "issuer", "created")
