@@ -109,19 +109,16 @@ class OPMetadata(BaseModel):
 
     @root_validator(pre=False)
     def validate(cls, values):
-        jwks = values.get("jwks")
-        jwks_uri = values.get("jwks_uri")
-        signed_jwks_uri = values.get("signed_jwks_uri")
-        if not jwks_uri and not jwks and not signed_jwks_uri:
+        jwks_there = False
+        for i in ("jwks_uri", "jwks", "signed_jwks_uri"):
+            if values.get(i):
+                jwks_there = True
+                break
+        
+        if not jwks_there:
             raise ValueError(
                 "one of signed_jwks_uri or jwks_uri or jwks must be set"
             )
-        if jwks_uri and jwks:
-            raise ValueError("can't use jwks and jwks_uri together")
-        elif jwks_uri and signed_jwks_uri:
-            raise ValueError(
-                "can't use signed_jwks_uri and jwks_uri together"
-            )
         return values
 
 
@@ -137,7 +134,5 @@ class OPMetadataCie(OPMetadata):
 
 
 class OPMetadataSpid(OPMetadata):
-    # TODO: Could be specified in multiple languages
-    op_name: str
-    # TODO: Could be specified in multiple languages
-    op_uri: str
+    op_name: Optional[str]
+    op_uri: Optional[str]
