@@ -1,6 +1,6 @@
-from typing import List, Literal, Optional
+from typing import Literal
 
-from pydantic import BaseModel, HttpUrl
+from pydantic import BaseModel
 
 
 class IntrospectionResponse(BaseModel):
